@@ -19,6 +19,7 @@
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -117,11 +118,11 @@
   ],
   era_abbreviated => [
     "BCE",
-    "CE",
+    "AD",
   ],
   era_narrow => [
     "BCE",
-    "CE",
+    "AD",
   ],
   era_wide => [
     "Saju Kristi",
@@ -267,5 +268,5 @@
   time_format_medium => "H:m:s",
   time_format_short => "H:m",
   variant => undef,
-  version => 35,
+  version => 41,
 }
